@@ -43,6 +43,7 @@ __all__ = (
     "ResourceTypeType",
     "RetryActionType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -340,10 +341,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -351,3 +354,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_compute_environments", "describe_job_definitions", "describe_job_queues", "list_jobs"
+]
